@@ -363,7 +363,13 @@ class AIDNEB:
 
         weight_update = self.input_param.weight
         scale_update = self.input_param.scale
-        # user_descriptor = self.input_param.descriptor
+
+        self.rmin = 0.1
+        max_weight = 5.0
+        violated_index = 0
+        set_update_step = False
+        update_step = 10
+
         while True:
 
             # 0. Start from initial interpolation every 50 steps.
@@ -393,9 +399,11 @@ class AIDNEB:
             print('Training data size: ', len(train_images))
             print('Descriptor: ', self.input_param.descriptor)
 
-            self.rmin = 0.1
-            max_weight = 5.0
-            if len(train_images) % 50 == 10:
+            if violated_index is None and not set_update_step:
+                update_step = self.step
+                set_update_step = True
+
+            if self.step % 25 == update_step:
                 self.input_param.fit_weight = True
                 self.input_param.fit_scale = True
 
@@ -425,7 +433,7 @@ class AIDNEB:
                             raise ValueError(f"Weight parameter too high ({train_data.calculator.weight}).")
 
                     except Exception as e:
-                        print(f"{e} Increasing r_min and retrying.")
+                        print(f"{e} Increase r_min to {self.rmin + 0.1} and retry.")
                         self.rmin += 0.1
 
                         train_data = ReferenceData(structure_files=train_images,
@@ -460,7 +468,7 @@ class AIDNEB:
                                              fit_weight=self.input_param.fit_weight,
                                              fit_scale=self.input_param.fit_scale)
 
-            self.rmin = 0.1
+            # self.rmin = 0.1
             print('r_min: ', self.rmin)
             print('GPR model hyperparameters: ', train_data.calculator.hyper_params)
 
@@ -518,7 +526,7 @@ class AIDNEB:
                         d2 = min_cartesian_dist(self.images[i], train_images)
                         if d2 > (self.rmax ** 2):
                             violated_index = i
-                            print("Relaxation early stop: the distance from current image {0} to the nearest training data point is larger than rmax".format(violated_index))
+                            print("Relaxation early stop: the distance from current image {0} to the nearest training data is larger than r_max".format(violated_index))
                             break
 
                     if violated_index is not None:
@@ -545,7 +553,9 @@ class AIDNEB:
             # 5. Print output.
             max_e = np.max(neb_pred_energy)
             max_e_ind = np.argsort(neb_pred_energy)[-1]
-            max_f = get_fmax(self.images[max_e_ind])  # get_fmax(train_images[-1]), train_images 의 calc 는 reference
+            # train_images 의 calc 는 reference,
+            # self.images 의 calc 는 GP
+            max_f = get_fmax(self.images[max_e_ind])  # get_fmax(train_images[-1])
 
             pbf = max_e - self.i_endpoint.get_potential_energy(force_consistent=self.force_consistent)
             pbb = max_e - self.e_endpoint.get_potential_energy(force_consistent=self.force_consistent)
@@ -581,7 +591,6 @@ class AIDNEB:
             # Candidates are the optimized NEB images in the predicted PES.
             candidates = copy.deepcopy(self.images)[1:-1]
 
-            print("violated_index:", violated_index)
             if violated_index is not None:
                 best_candidate = candidates[violated_index]
                 sorted_candidates = False
